%global nagios_plugins_dir %{_libdir}/nagios/plugins

%define _disable_ld_no_undefined 1

%global errmsg_dir %{_datadir}/mysql/default

Summary:	A database-centric proxy that works with MariaDB and MySQL
Name:		maxscale
Version:	1.3.0
Release:	%mkrel 7
License:	GPLv2+
Group:		System/Servers
URL:		https://mariadb.com/products/mariadb-maxscale
Source0:	https://github.com/mariadb-corporation/MaxScale/archive/%{version}/MaxScale-%{version}.tar.gz
Source1:	maxscale.service
Source2:	maxscale.logrotate.systemd
Source3:	maxscale.profile.d
Source4:	maxscale.sysconfig
Source5:	maxscale.tmpfiles.d
Patch0:		maxscale-sysconfdir.patch
Patch1:		MaxScale-1.3.0-no_hardcoded_CMAKE_INSTALL_PREFIX.diff
Patch2:		MaxScale-1.3.0-no_werror.diff
# https://jira.mariadb.org/browse/MXS-597
# https://github.com/mariadb-corporation/MaxScale/commit/9b8b7ee576c8d8275147fd53744a4d488b719cfb
Patch3:		0026-Added-support-for-system-PCRE2.patch
BuildRequires:	bison
BuildRequires:	bzip2-devel
BuildRequires:	cmake
BuildRequires:	curl-devel
BuildRequires:	libaio-devel
BuildRequires:	libedit-devel
BuildRequires:	mysql-embedded-devel
BuildRequires:	ncurses-devel
BuildRequires:	openssl-devel
BuildRequires:	systemd-units
BuildRequires:	systemtap
BuildRequires:	pkgconfig(libpcre2-8) >= 10.21
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1
Requires(pre): rpm-helper >= 0.24.8-1

%description
MaxScale is an open-source, database-centric proxy that works with MariaDB and
MySQL

It has a pluggable architecture designed to increase flexibility and aid
customisation as well as a lightweight, high-speed networking core designed to
facilitate throughput.

MaxScale runs between the client application and the database cluster and
currently offers connection and statement-based load balancing.

%package -n     nagios-%{name}
Summary:        Nagios plugins to monitor MaxScale
Group:          Monitoring
Requires:       nagios

%description -n nagios-%{name}
These plugins allow you to monitor MaxScale monitors, resources and threads.

%prep

%setup -q -n MaxScale-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

perl -pi -e "s|-Wall -fPIC|%{optflags} -fPIC|g" CMakeLists.txt

# revert set_target_properties, we want "modules" here
find -name "CMakeLists.txt" | xargs perl -pi -e "s|^set_target_properties|#set_target_properties|g"

# but shared libraries here
perl -pi -e "s|#set_target_properties|set_target_properties|g" log_manager/CMakeLists.txt
perl -pi -e "s|#set_target_properties|set_target_properties|g" query_classifier/CMakeLists.txt

%build

%cmake \
    -DSTATIC_EMBEDDED=false \
    -DEMBEDDED_LIB=%{_libdir} \
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DWITH_SCRIPTS=N \
    -DBUILD_SHARED_LIBS=N \
    -DERRMSG=%{errmsg_dir}

# the package now uses rpath in order to link with modules located at /usr/lib64/maxscale/
#    -DCMAKE_SKIP_RPATH=1 \

make VERBOSE=1

# %check
# tests TestModutil and TestService fail now
# export LD_LIBRARY_PATH=$(pwd)/server/modules/protocol
# make testcore || :

%install

make -C build install DESTDIR=%{buildroot}
rm -rf %{buildroot}%{_sysconfdir}/init.d
rm -rf %{buildroot}%{_localstatedir}/lib/maxscale/errmsg.sys
install -d %{buildroot}%{_localstatedir}/lib/maxscale
ln -s %{errmsg_dir}/errmsg.sys %{buildroot}%{_localstatedir}/lib/maxscale/errmsg.sys

install -d %{buildroot}%{_sysconfdir}/logrotate.d
install -d %{buildroot}%{_localstatedir}/lib/%{name}/{mysql,etc}
install -d %{buildroot}%{_tmpfilesdir}
install -d %{buildroot}%{_localstatedir}/log/%{name}
install -d %{buildroot}%{_localstatedir}/run/%{name}
install -d %{buildroot}%{_unitdir}
install -m0644 %{SOURCE1} %{buildroot}%{_unitdir}/
install -m0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -p -m 0644 %{SOURCE5} %{buildroot}%{_tmpfilesdir}/%{name}.conf
ln -s %{_localstatedir}/run/maxscale %{buildroot}%{_localstatedir}/lib/%{name}/run

# in order to teach rpm not to mess with it.
touch %{buildroot}%{_localstatedir}/lib/%{name}/etc/.secrets

# move run time shared libraries in place
mv %{buildroot}%{_libdir}/%{name}/liblog_manager.so* %{buildroot}%{_libdir}/
mv %{buildroot}%{_libdir}/%{name}/libquery_classifier.so* %{buildroot}%{_libdir}/

# provide the config
mv %{buildroot}%{_sysconfdir}/maxscale.cnf.template %{buildroot}%{_sysconfdir}/maxscale.cnf

# rearrange docs and files
rm -rf %{buildroot}%{_datadir}/%{name}

# nagios plugins
install -d -m 755 %{buildroot}%{nagios_plugins_dir}
install -p -m 755 plugins/nagios/*.pl %{buildroot}%{nagios_plugins_dir}

install -d -m 0755 %{buildroot}%{_sysconfdir}/nagios/conf.d/
install -p -m 644 plugins/nagios/maxscale_commands.cfg %{buildroot}%{_sysconfdir}/nagios/conf.d/%{name}.cfg

%pre
%_pre_useradd %{name} %{_localstatedir}/lib/%{name} /sbin/nologin

%post
# generate the unique .secrets file
if [ -e %{_localstatedir}/lib/%{name}/etc/.secrets ]; then
    MAXSCALE_HOME=%{_localstatedir}/lib/%{name} %{_bindir}/maxkeys %{_localstatedir}/lib/%{name}/etc/
    chmod 0400 %{_localstatedir}/lib/%{name}/etc/.secrets
    chown %{name}:%{name} %{_localstatedir}/lib/%{name}/etc/.secrets
fi
%_post_service %{name}
%_tmpfilescreate %{name}

%preun
%_preun_service %{name}

%files
%doc COPYRIGHT LICENSE README 
%doc etc/lsyncd_example.conf server/maxscale_binlogserver_template.cnf server/maxscale_template.cnf
%doc build/Changelog.txt build/ReleaseNotes.txt build/UpgradingToMaxScale12.txt
%{_bindir}/*
%{_libdir}/%{name}/*.so
%{_libdir}/liblog_manager.so*
%{_libdir}/libquery_classifier.so*
%dir %{_libdir}/%{name}
%{_unitdir}/%{name}.service
%attr(0400,%{name},%{name}) %config(noreplace) %{_localstatedir}/lib/maxscale/etc/.secrets
%attr(0750,%{name},%{name}) %dir %{_localstatedir}/log/%{name}
%attr(0750,%{name},%{name}) %dir %{_localstatedir}/lib/%{name}
%dir %{_localstatedir}/lib/%{name}/mysql
%{_localstatedir}/lib/%{name}/errmsg.sys
%attr(0755,%{name},%{name}) %ghost %dir %{_localstatedir}/run/%{name}
%{_localstatedir}/lib/%{name}/run
%attr(0640,root,%{name}) %config(noreplace) %{_sysconfdir}/%{name}.cnf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_tmpfilesdir}/%{name}.conf
%{_mandir}/man1/maxscale.1.*

%files -n nagios-%{name}
%doc LICENSE plugins/nagios/server1.cfg
%config(noreplace) %{_sysconfdir}/nagios/conf.d/%{name}.cfg
%{nagios_plugins_dir}/check_maxscale_monitors.pl
%{nagios_plugins_dir}/check_maxscale_resources.pl
%{nagios_plugins_dir}/check_maxscale_threads.pl


%changelog
* Thu Mar 10 2016 oden <oden> 1.3.0-7.mga6
+ Revision: 988714
- bump release
- fix group
- fix file lists
- rearrange docs and files
- added the nagios-maxscale sub package

* Mon Mar 07 2016 oden <oden> 1.3.0-5.mga6
+ Revision: 987178
- build against system pcre2 libs

* Wed Mar 02 2016 umeabot <umeabot> 1.3.0-4.mga6
+ Revision: 983650
- Rebuild for openssl

* Sat Feb 27 2016 oden <oden> 1.3.0-3.mga6
+ Revision: 980069
- use %%ghost
- bump release
- rule out -Werror
- bs borkiness?
- whoops!
- 1.3.0
- synced a bit with the work by Honza Horak (https://bugzilla.redhat.com/show_bug.cgi?id=1083962)
- major changes
- note: pcre2 is bundled, built and used. needs cmake magic to avoid that.

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.7.0-4.mga5
+ Revision: 741557
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.7.0-3.mga5
+ Revision: 682305
- Mageia 5 Mass Rebuild

* Tue Aug 12 2014 oden <oden> 0.7.0-2.mga5
+ Revision: 662043
- rebuilt for mariadb-10.0.13

* Mon Jun 16 2014 oden <oden> 0.7.0-1.mga5
+ Revision: 637460
- 0.7.0

* Tue May 13 2014 oden <oden> 0.6.0-1.mga5
+ Revision: 622446
- 0.6.0

* Fri Apr 04 2014 oden <oden> 0.5.0-3.mga5
+ Revision: 611623
- run the server as the maxscale user
- various spec file cleanups

* Thu Apr 03 2014 oden <oden> 0.5.0-2.mga5
+ Revision: 611462
- better fix
- hmm...
- various spec file fixes
- added one important upstream patch (ignore /etc/my.cnf)

* Mon Mar 31 2014 oden <oden> 0.5.0-1.mga5
+ Revision: 610933
- 0.5.0 (final)

* Sat Mar 29 2014 oden <oden> 0.5.0-0.4.mga5
+ Revision: 609305
- added systemd support
- generate the .secrets file at install
- phew. getting sloppy

* Sat Mar 29 2014 oden <oden> 0.5.0-0.3.mga5
+ Revision: 609282
- no use making the maxscale user, yet
- make it work a little better
- oops, one faulty softlink

* Fri Mar 28 2014 oden <oden> 0.5.0-0.2.mga5
+ Revision: 609084
- use the 0.5 branch with format string fixes
- use %%{optflags} and %%{ldflags} with some undefined fixes in P0

* Fri Mar 28 2014 oden <oden> 0.5.0-0.1.mga5
+ Revision: 609070
- simplify a bit and use the /etc/sysconfig/maxscale to set options

* Thu Mar 27 2014 oden <oden> 0.5.0-0.0.mga5
+ Revision: 608997
- try to fix rpmlint errors
- fix deps
- imported package maxscale

